@@ -3,7 +3,7 @@ package tfexec
 import (
 	"context"
 	"fmt"
-	"io/ioutil"
+	"os"
 	"reflect"
 	"regexp"
 	"strings"
@@ -20,7 +20,7 @@ func TestTerraformCLIImport(t *testing.T) {
 		for _, arg := range args {
 			if strings.HasPrefix(arg, "-state-out=") {
 				stateOutFile := arg[len("-state-out="):]
-				return ioutil.WriteFile(stateOutFile, stateOut.Bytes(), 0600)
+				return os.WriteFile(stateOutFile, stateOut.Bytes(), 0600)
 			}
 		}
 		return fmt.Errorf("failed to find -state-out= option: %v", args)
